# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`ssh`](#ssh): Sets up files for ssh.
* [`ssh::authorized_keys`](#ssh--authorized_keys): Add `ssh_authorized_keys` via hiera in a loop
* [`ssh::client`](#ssh--client): Sets up a ssh client and creates /etc/ssh/ssh_config.
* [`ssh::client::params`](#ssh--client--params): Default parameters for the SSH client
* [`ssh::server`](#ssh--server): Sets up a ssh server and starts sshd.
* [`ssh::server::conf`](#ssh--server--conf): Sets up sshd_config and adds an iptables rule if iptables is being used.
* [`ssh::server::params`](#ssh--server--params): Default parameters for the SSH Server

### Defined types

* [`ssh::client::host_config_entry`](#ssh--client--host_config_entry): Creates a host entry to ssh_config

### Resource types

* [`sshkey_prune`](#sshkey_prune): The file that you wish to prune

### Functions

* [`ssh::add_sshd_config`](#ssh--add_sshd_config): Add a sshd_config entry if it is not in the remove list
* [`ssh::autokey`](#ssh--autokey): Generates a random RSA SSH private and public key pair for a passed
* [`ssh::config_bool_translate`](#ssh--config_bool_translate): Translates true|false or 'true'|'false' to 'yes'|'no', respectively
* [`ssh::format_host_entry_for_sorting`](#ssh--format_host_entry_for_sorting): A method to sensibly format sort SSH 'host' entries which contain
* [`ssh::global_known_hosts`](#ssh--global_known_hosts): Update the ssh_known_hosts files for all hosts, purging old files,
* [`ssh::parse_ssh_pubkey`](#ssh--parse_ssh_pubkey): Take an ssh pubkey that looks like:   ssh-rsa jdlkfgjsdfo;i... user@domain.com and turn it into a hash, usable in the ssh_authorized_key type

### Data types

* [`Ssh::Authentications`](#Ssh--Authentications): Valid SSH Authentication Settings
* [`Ssh::Loglevel`](#Ssh--Loglevel): Valid SSH Loglevels
* [`Ssh::PermitRootLogin`](#Ssh--PermitRootLogin): Valid Settings for PermitRootLogin
* [`Ssh::Syslogfacility`](#Ssh--Syslogfacility): Valid SSH Syslog Facility Settings

## Classes

### <a name="ssh"></a>`ssh`

Sets up files for ssh.

#### Parameters

The following parameters are available in the `ssh` class:

* [`enable_client`](#-ssh--enable_client)
* [`enable_server`](#-ssh--enable_server)

##### <a name="-ssh--enable_client"></a>`enable_client`

Data type: `Boolean`

If true, set up the SSH client configuration files.

Default value: `true`

##### <a name="-ssh--enable_server"></a>`enable_server`

Data type: `Boolean`

If true, set up an SSH server on the system.

Default value: `true`

### <a name="ssh--authorized_keys"></a>`ssh::authorized_keys`

This class was designed so you can just paste the output of the ssh pubkey into
hiera and it will work. See the example below for details.

> **WARNING**
>
> This creates a user for every key and every user in the Hash. If this is
> large, please consider moving to a central source for these keys, such as
> LDAP, so that you do not over-burden your Puppet server.
>
> **WARNING**

* **See also**
  * https://puppet.com/docs/puppet/5.5/types/ssh_authorized_key.html

#### Examples

##### Adding user keys via Hiera

```puppet
---
ssh::authorized_keys::keys:
  kelly: ssh-rsa skjfhslkdjfs...
  nick:
  - ssh-rsa sajhgfsaihd...
  - ssh-rsa jrklsahsgfs...
  mike:
    key: dlfkjsahh...
    type: ssh-rsa
    user: mlast
    target: /home/gitlab-runner/.ssh/authorized_keys
```

#### Parameters

The following parameters are available in the `ssh::authorized_keys` class:

* [`keys`](#-ssh--authorized_keys--keys)

##### <a name="-ssh--authorized_keys--keys"></a>`keys`

Data type: `Hash`

The hash to generate key resouces from

Default value: `{}`

### <a name="ssh--client"></a>`ssh::client`

Sets up a ssh client and creates /etc/ssh/ssh_config.

#### Parameters

The following parameters are available in the `ssh::client` class:

* [`add_default_entry`](#-ssh--client--add_default_entry)
* [`fips`](#-ssh--client--fips)
* [`haveged`](#-ssh--client--haveged)
* [`package_ensure`](#-ssh--client--package_ensure)

##### <a name="-ssh--client--add_default_entry"></a>`add_default_entry`

Data type: `Boolean`

Set this if you wish to automatically
have the '*' Host entry set up with some sane defaults.

Default value: `true`

##### <a name="-ssh--client--fips"></a>`fips`

Data type: `Boolean`

If set or FIPS is already enabled, adjust for FIPS mode.

Default value: `simplib::lookup('simp_options::fips', { 'default_value' => false })`

##### <a name="-ssh--client--haveged"></a>`haveged`

Data type: `Boolean`

If true, include the haveged module to assist with entropy generation.

Default value: `simplib::lookup('simp_options::haveged', { 'default_value' => false })`

##### <a name="-ssh--client--package_ensure"></a>`package_ensure`

Data type: `String`

The ensure status the openssh-clients package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="ssh--client--params"></a>`ssh::client::params`

Default parameters for the SSH client

### <a name="ssh--server"></a>`ssh::server`

Sets up a ssh server and starts sshd.

#### Parameters

The following parameters are available in the `ssh::server` class:

* [`server_ensure`](#-ssh--server--server_ensure)
* [`ldap_ensure`](#-ssh--server--ldap_ensure)

##### <a name="-ssh--server--server_ensure"></a>`server_ensure`

Data type: `String`

The ensure status of the openssh-server package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-ssh--server--ldap_ensure"></a>`ldap_ensure`

Data type: `String`

The ensure status of the openssh-ldap package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="ssh--server--conf"></a>`ssh::server::conf`

``sshd`` configuration variables can be set using Augeas outside of this
class with no adverse effects.

SSH Parameters ####

Custom Parameters ####

SIMP Parameters ####

#### Parameters

The following parameters are available in the `ssh::server::conf` class:

* [`acceptenv`](#-ssh--server--conf--acceptenv)
* [`allowgroups`](#-ssh--server--conf--allowgroups)
* [`allowusers`](#-ssh--server--conf--allowusers)
* [`manage_authorizedkeysfile`](#-ssh--server--conf--manage_authorizedkeysfile)
* [`authorizedkeysfile`](#-ssh--server--conf--authorizedkeysfile)
* [`authorizedkeyscommand`](#-ssh--server--conf--authorizedkeyscommand)
* [`authorizedkeyscommanduser`](#-ssh--server--conf--authorizedkeyscommanduser)
* [`banner`](#-ssh--server--conf--banner)
* [`challengeresponseauthentication`](#-ssh--server--conf--challengeresponseauthentication)
* [`ciphers`](#-ssh--server--conf--ciphers)
* [`clientalivecountmax`](#-ssh--server--conf--clientalivecountmax)
* [`clientaliveinterval`](#-ssh--server--conf--clientaliveinterval)
* [`compression`](#-ssh--server--conf--compression)
* [`denygroups`](#-ssh--server--conf--denygroups)
* [`denyusers`](#-ssh--server--conf--denyusers)
* [`gssapiauthentication`](#-ssh--server--conf--gssapiauthentication)
* [`hostbasedauthentication`](#-ssh--server--conf--hostbasedauthentication)
* [`ignorerhosts`](#-ssh--server--conf--ignorerhosts)
* [`ignoreuserknownhosts`](#-ssh--server--conf--ignoreuserknownhosts)
* [`kerberosauthentication`](#-ssh--server--conf--kerberosauthentication)
* [`kex_algorithms`](#-ssh--server--conf--kex_algorithms)
* [`listenaddress`](#-ssh--server--conf--listenaddress)
* [`logingracetime`](#-ssh--server--conf--logingracetime)
* [`ssh_loglevel`](#-ssh--server--conf--ssh_loglevel)
* [`macs`](#-ssh--server--conf--macs)
* [`maxauthtries`](#-ssh--server--conf--maxauthtries)
* [`passwordauthentication`](#-ssh--server--conf--passwordauthentication)
* [`permitemptypasswords`](#-ssh--server--conf--permitemptypasswords)
* [`permitrootlogin`](#-ssh--server--conf--permitrootlogin)
* [`permituserenvironment`](#-ssh--server--conf--permituserenvironment)
* [`port`](#-ssh--server--conf--port)
* [`printlastlog`](#-ssh--server--conf--printlastlog)
* [`protocol`](#-ssh--server--conf--protocol)
* [`rhostsrsaauthentication`](#-ssh--server--conf--rhostsrsaauthentication)
* [`strictmodes`](#-ssh--server--conf--strictmodes)
* [`subsystem`](#-ssh--server--conf--subsystem)
* [`syslogfacility`](#-ssh--server--conf--syslogfacility)
* [`tcpwrappers`](#-ssh--server--conf--tcpwrappers)
* [`usepam`](#-ssh--server--conf--usepam)
* [`manage_pam_sshd`](#-ssh--server--conf--manage_pam_sshd)
* [`oath`](#-ssh--server--conf--oath)
* [`oath_window`](#-ssh--server--conf--oath_window)
* [`useprivilegeseparation`](#-ssh--server--conf--useprivilegeseparation)
* [`x11forwarding`](#-ssh--server--conf--x11forwarding)
* [`custom_entries`](#-ssh--server--conf--custom_entries)
* [`remove_entries`](#-ssh--server--conf--remove_entries)
* [`remove_subsystems`](#-ssh--server--conf--remove_subsystems)
* [`app_pki_external_source`](#-ssh--server--conf--app_pki_external_source)
* [`app_pki_key`](#-ssh--server--conf--app_pki_key)
* [`enable_fallback_ciphers`](#-ssh--server--conf--enable_fallback_ciphers)
* [`fallback_ciphers`](#-ssh--server--conf--fallback_ciphers)
* [`fips`](#-ssh--server--conf--fips)
* [`firewall`](#-ssh--server--conf--firewall)
* [`haveged`](#-ssh--server--conf--haveged)
* [`ldap`](#-ssh--server--conf--ldap)
* [`pki`](#-ssh--server--conf--pki)
* [`sssd`](#-ssh--server--conf--sssd)
* [`ensure_sssd_packages`](#-ssh--server--conf--ensure_sssd_packages)
* [`trusted_nets`](#-ssh--server--conf--trusted_nets)

##### <a name="-ssh--server--conf--acceptenv"></a>`acceptenv`

Data type: `Array[String]`

Specifies what environment variables sent by the client will be copied into
the sessions environment.

Default value: `$ssh::server::params::acceptenv`

##### <a name="-ssh--server--conf--allowgroups"></a>`allowgroups`

Data type: `Optional[Array[String]]`

A list of group name patterns. If specified, login is allowed only for
users whose primary or supplementary group list matches one of the
patterns.

Default value: `undef`

##### <a name="-ssh--server--conf--allowusers"></a>`allowusers`

Data type: `Optional[Array[String]]`

A list of user name patterns. If specified, login is allowed only for users
whose name matches one of the patterns.

Default value: `undef`

##### <a name="-ssh--server--conf--manage_authorizedkeysfile"></a>`manage_authorizedkeysfile`

Data type: `Boolean`

This will allow users to opt out of puppet managing their ssh authorized
keys file. If set to false, authorizedkeysfile will be ignored.

Default value: `true`

##### <a name="-ssh--server--conf--authorizedkeysfile"></a>`authorizedkeysfile`

Data type: `String`

This is set to a non-standard location to provide for increased control
over who can log in as a given user.

Default value: `'/etc/ssh/local_keys/%u'`

##### <a name="-ssh--server--conf--authorizedkeyscommand"></a>`authorizedkeyscommand`

Data type: `Optional[Stdlib::Absolutepath]`

Specifies a program to be used for lookup of the user's public keys.

Default value: `undef`

##### <a name="-ssh--server--conf--authorizedkeyscommanduser"></a>`authorizedkeyscommanduser`

Data type: `String`

Specifies the user under whose account the AuthorizedKeysCommand is run.

Default value: `'nobody'`

##### <a name="-ssh--server--conf--banner"></a>`banner`

Data type: `Stdlib::Absolutepath`

The contents of the specified file are sent to the remote user before
authentication is allowed.

Default value: `'/etc/issue.net'`

##### <a name="-ssh--server--conf--challengeresponseauthentication"></a>`challengeresponseauthentication`

Data type: `Boolean`

Specifies whether challenge-response authentication is allowed.

Default value: `false`

##### <a name="-ssh--server--conf--ciphers"></a>`ciphers`

Data type: `Optional[Array[String]]`

Specifies the ciphers allowed for protocol version 2.  When unset, a strong
set of ciphers is automatically selected by this class, taking into account
whether the server is in FIPS mode.

Default value: `undef`

##### <a name="-ssh--server--conf--clientalivecountmax"></a>`clientalivecountmax`

Data type: `Integer`

@see man page for sshd_config

Default value: `0`

##### <a name="-ssh--server--conf--clientaliveinterval"></a>`clientaliveinterval`

Data type: `Integer`

@see man page for sshd_config

Default value: `600`

##### <a name="-ssh--server--conf--compression"></a>`compression`

Data type: `Variant[Boolean,Enum['delayed']]`

Specifies whether compression is allowed, or delayed until the user has
authenticated successfully.

Default value: `'delayed'`

##### <a name="-ssh--server--conf--denygroups"></a>`denygroups`

Data type: `Optional[Array[String]]`

A list of group name patterns.  If specified, login is disallowed for users
whose primary or supplementary group list matches one of the patterns.

Default value: `undef`

##### <a name="-ssh--server--conf--denyusers"></a>`denyusers`

Data type: `Optional[Array[String]]`

A list of user name patterns.  If specified, login is disallowed for users
whose name matches one of the patterns.

Default value: `undef`

##### <a name="-ssh--server--conf--gssapiauthentication"></a>`gssapiauthentication`

Data type: `Boolean`

Specifies whether user authentication based on GSSAPI is allowed. If the
system is connected to an IPA domain, this will be default to true, based
on the existance of the `ipa` fact.

Default value: `$ssh::server::params::gssapiauthentication`

##### <a name="-ssh--server--conf--hostbasedauthentication"></a>`hostbasedauthentication`

Data type: `Boolean`

@see man page for sshd_config

Default value: `false`

##### <a name="-ssh--server--conf--ignorerhosts"></a>`ignorerhosts`

Data type: `Boolean`

@see man page for sshd_config

Default value: `true`

##### <a name="-ssh--server--conf--ignoreuserknownhosts"></a>`ignoreuserknownhosts`

Data type: `Boolean`

@see man page for sshd_config

Default value: `true`

##### <a name="-ssh--server--conf--kerberosauthentication"></a>`kerberosauthentication`

Data type: `Boolean`

@see man page for sshd_config

Default value: `false`

##### <a name="-ssh--server--conf--kex_algorithms"></a>`kex_algorithms`

Data type: `Optional[Array[String]]`

Specifies the key exchange algorithms accepted.  When unset, an appropriate
set of algorithms is automatically selected by this class, taking into
account whether the server is in FIPS mode and whether the version of
openssh installed supports this feature.

Default value: `undef`

##### <a name="-ssh--server--conf--listenaddress"></a>`listenaddress`

Data type: `Optional[Variant[Simplib::Host, Array[Simplib::Host]]]`

Specifies the local addresses sshd should listen on.

Default value: `undef`

##### <a name="-ssh--server--conf--logingracetime"></a>`logingracetime`

Data type: `Integer[0]`

The max number of seconds the server will wait for a successful login
before disconnecting. If the value is 0, there is no limit.

Default value: `120`

##### <a name="-ssh--server--conf--ssh_loglevel"></a>`ssh_loglevel`

Data type: `Optional[Ssh::Loglevel]`

Specifies the verbosity level that is used when logging messages from sshd.

Default value: `undef`

##### <a name="-ssh--server--conf--macs"></a>`macs`

Data type: `Optional[Array[String]]`

Specifies the available MAC algorithms. When unset, a strong set of ciphers
is automatically selected by this class, taking into account whether the
server is in FIPS mode.

Default value: `undef`

##### <a name="-ssh--server--conf--maxauthtries"></a>`maxauthtries`

Data type: `Integer[1]`

Specifies the maximum number of authentication attempts permitted per
connection.

Default value: `6`

##### <a name="-ssh--server--conf--passwordauthentication"></a>`passwordauthentication`

Data type: `Boolean`

Specifies whether password authentication is allowed on the sshd server.

* This setting must be managed by default so that switching to and from
  OATH does not lock you out of your system.

Default value: `true`

##### <a name="-ssh--server--conf--permitemptypasswords"></a>`permitemptypasswords`

Data type: `Boolean`

When password authentication is allowed, it specifies whether the server
allows login to accounts with empty password strings.

Default value: `false`

##### <a name="-ssh--server--conf--permitrootlogin"></a>`permitrootlogin`

Data type: `Ssh::PermitRootLogin`

Specifies whether root can log in using SSH.

Default value: `false`

##### <a name="-ssh--server--conf--permituserenvironment"></a>`permituserenvironment`

Data type: `Boolean`

@see man page for sshd_config

Default value: `false`

##### <a name="-ssh--server--conf--port"></a>`port`

Data type: `Variant[Array[Simplib::Port],Simplib::Port]`

Specifies the port number SSHD listens on.

Default value: `22`

##### <a name="-ssh--server--conf--printlastlog"></a>`printlastlog`

Data type: `Boolean`

Specifies whether SSHD should print the date and time of the last user
login when a user logs in interactively.

Default value: `false`

##### <a name="-ssh--server--conf--protocol"></a>`protocol`

Data type: `Array[Integer[1,2]]`

@see man page for sshd_config

Default value: `[2]`

##### <a name="-ssh--server--conf--rhostsrsaauthentication"></a>`rhostsrsaauthentication`

Data type: `Optional[Boolean]`

This sshd option has been completely removed in openssh 7.4 and
will cause an error message to be logged, when present.  On systems
using openssh 7.4 or later, only set this value if you need
`RhostsRSAAuthentication` to be in the sshd configuration file to
satisfy an outdated, STIG check.

Default value: `$ssh::server::params::rhostsrsaauthentication`

##### <a name="-ssh--server--conf--strictmodes"></a>`strictmodes`

Data type: `Boolean`

@see man page for sshd_config

Default value: `true`

##### <a name="-ssh--server--conf--subsystem"></a>`subsystem`

Data type: `String`

Configures an external subsystem for file transfers.

Default value: `'sftp /usr/libexec/openssh/sftp-server'`

##### <a name="-ssh--server--conf--syslogfacility"></a>`syslogfacility`

Data type: `Ssh::Syslogfacility`

Gives the facility code that is used when logging messages.

Default value: `'AUTHPRIV'`

##### <a name="-ssh--server--conf--tcpwrappers"></a>`tcpwrappers`

Data type: `Boolean`

If true, enable sshd tcpwrappers.

Default value: `simplib::lookup('simp_options::tcpwrappers', { 'default_value' => false })`

##### <a name="-ssh--server--conf--usepam"></a>`usepam`

Data type: `Boolean`

Enables the Pluggable Authentication Module interface.

Default value: `simplib::lookup('simp_options::pam', { 'default_value' => true })`

##### <a name="-ssh--server--conf--manage_pam_sshd"></a>`manage_pam_sshd`

Data type: `Boolean`

Flag indicating whether or not to manage the pam stack for sshd. This is
required for the oath option to work properly.

Default value: `$oath`

##### <a name="-ssh--server--conf--oath"></a>`oath`

Data type: `Boolean`

**EXPERIMENTAL FEATURE**
Configures ssh to use pam_oath TOTP in the sshd pam stack.
Also configures sshd_config to use required settings. Inherits from
simp_options::oath, defaults to false if not found.

Default value: `simplib::lookup('simp_options::oath', { 'default_value' => false })`

##### <a name="-ssh--server--conf--oath_window"></a>`oath_window`

Data type: `Integer[0]`

Sets the TOTP window (Defined in RFC 6238 section 5.2)

Default value: `1`

##### <a name="-ssh--server--conf--useprivilegeseparation"></a>`useprivilegeseparation`

Data type: `Variant[Boolean,Enum['sandbox']]`

Specifies whether sshd separates privileges by creating an unprivileged
child process to deal with incoming network traffic.

This option has no effect on OpenSSH >= 7.5.0 due to being deprecated.

Default value: `'sandbox'`

##### <a name="-ssh--server--conf--x11forwarding"></a>`x11forwarding`

Data type: `Boolean`

Specifies whether X11 forwarding is permitted.

Default value: `false`

##### <a name="-ssh--server--conf--custom_entries"></a>`custom_entries`

Data type: `Optional[Hash[String[1],NotUndef]]`

A Hash of key/value pairs that will be added as ``sshd_config`` resources
without any validation.

* NOTE: Due to complexity, ``Match`` entries are not supported and will
  need to be added using ``sshd_config_match`` resources as described in
  ``augeasproviders_ssh``

@example Set AuthorizedPrincipalsCommand
  ---
  ssh::server::conf::custom_entries:
    AuthorizedPrincipalsCommand: '/usr/local/bin/my_auth_command'

Default value: `undef`

##### <a name="-ssh--server--conf--remove_entries"></a>`remove_entries`

Data type: `Optional[Array[String[1]]]`

List of configuration parameters that will be removed.

* NOTE: Due to complexity, ``Match`` entries are not supported and will
  need to be removed using ``sshd_config_match`` resources as described in
  ``augeasproviders_ssh``

Default value: `undef`

##### <a name="-ssh--server--conf--remove_subsystems"></a>`remove_subsystems`

Data type: `Optional[Array[String[1]]]`

List of subsystems that will be removed.

Default value: `undef`

##### <a name="-ssh--server--conf--app_pki_external_source"></a>`app_pki_external_source`

Data type: `String`

* If pki = 'simp' or true, this is the directory from which certs will be
  copied, via pki::copy.  Defaults to /etc/pki/simp/x509.

* If pki = false, this variable has no effect.

Default value: `simplib::lookup('simp_options::pki::source', { 'default_value' => '/etc/pki/simp/x509' })`

##### <a name="-ssh--server--conf--app_pki_key"></a>`app_pki_key`

Data type: `Stdlib::Absolutepath`

Path and name of the private SSL key file. This key file is used to generate
the system SSH certificates for consistency.

Default value: `"/etc/pki/simp_apps/sshd/x509/private/${facts['networking']['fqdn']}.pem"`

##### <a name="-ssh--server--conf--enable_fallback_ciphers"></a>`enable_fallback_ciphers`

Data type: `Boolean`

If true, add the fallback ciphers from ssh::server::params to the cipher
list. This is intended to provide compatibility with non-SIMP systems in a
way that properly supports FIPS 140-2.

Default value: `true`

##### <a name="-ssh--server--conf--fallback_ciphers"></a>`fallback_ciphers`

Data type: `Array[String]`

The set of ciphers that should be used should no other cipher be declared.
This is used when $ssh::server::conf::enable_fallback_ciphers is enabled.

Default value: `$ssh::server::params::fallback_ciphers`

##### <a name="-ssh--server--conf--fips"></a>`fips`

Data type: `Boolean`

If set or FIPS is already enabled, adjust for FIPS mode.

Default value: `simplib::lookup('simp_options::fips', { 'default_value' => false })`

##### <a name="-ssh--server--conf--firewall"></a>`firewall`

Data type: `Boolean`

If true, use the SIMP iptables class.

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false })`

##### <a name="-ssh--server--conf--haveged"></a>`haveged`

Data type: `Boolean`

If true, include the haveged module to assist with entropy generation.

Default value: `simplib::lookup('simp_options::haveged', { 'default_value' => false })`

##### <a name="-ssh--server--conf--ldap"></a>`ldap`

Data type: `Boolean`

If true, enable LDAP support on the system. If
authorizedkeyscommand is empty, this will set the authorizedkeyscommand to
ssh-ldap-wrapper so that SSH public keys can be stored directly in LDAP.

Default value: `simplib::lookup('simp_options::ldap', { 'default_value' => false })`

##### <a name="-ssh--server--conf--pki"></a>`pki`

Data type: `Variant[Enum['simp'],Boolean]`

* If 'simp', include SIMP's pki module and use pki::copy to manage
  application certs in /etc/pki/simp_apps/sshd/x509
* If true, do *not* include SIMP's pki module, but still use pki::copy
  to manage certs in /etc/pki/simp_apps/sshd/x509
* If false, do not include SIMP's pki module and do not use pki::copy
  to manage certs.  You will need to appropriately assign a subset of:
  * app_pki_dir
  * app_pki_key
  * app_pki_cert
  * app_pki_ca
  * app_pki_ca_dir

Default value: `simplib::lookup('simp_options::pki', { 'default_value' => false })`

##### <a name="-ssh--server--conf--sssd"></a>`sssd`

Data type: `Boolean`

If true, use sssd

Default value: `simplib::lookup('simp_options::sssd', { 'default_value' => false })`

##### <a name="-ssh--server--conf--ensure_sssd_packages"></a>`ensure_sssd_packages`

Data type: `Variant[Boolean,Array[String[1]]]`

A list of SSSD-related packages to ensure are installed on the system.

* Set to `false` to prevent package management.

Default value: `['sssd-common']`

##### <a name="-ssh--server--conf--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

The networks to allow to connect to SSH.

Default value: `['ALL']`

### <a name="ssh--server--params"></a>`ssh::server::params`

* ``Curve`` exchange was not fully supported until openssh 6.5
* RhostsRSAAuthentication was removed in openssh 7.4

## Defined types

### <a name="ssh--client--host_config_entry"></a>`ssh::client::host_config_entry`

GSSAPI may be used.

the client's GSSAPI credentials will force the rekeying of the ssh connection.

trusted to securely canonicalize the name of the host being connected to.

#### Examples

##### Adding default entry

```puppet

ssh::client::host_config_entry { '*':
  gssapiauthentication => true,
  forwardx11trusted    => true'
}
```

#### Parameters

The following parameters are available in the `ssh::client::host_config_entry` defined type:

* [`target`](#-ssh--client--host_config_entry--target)
* [`address_family`](#-ssh--client--host_config_entry--address_family)
* [`batchmode`](#-ssh--client--host_config_entry--batchmode)
* [`bindaddress`](#-ssh--client--host_config_entry--bindaddress)
* [`challengeresponseauthentication`](#-ssh--client--host_config_entry--challengeresponseauthentication)
* [`checkhostip`](#-ssh--client--host_config_entry--checkhostip)
* [`cipher`](#-ssh--client--host_config_entry--cipher)
* [`ciphers`](#-ssh--client--host_config_entry--ciphers)
* [`clearallforwardings`](#-ssh--client--host_config_entry--clearallforwardings)
* [`compression`](#-ssh--client--host_config_entry--compression)
* [`compressionlevel`](#-ssh--client--host_config_entry--compressionlevel)
* [`connectionattempts`](#-ssh--client--host_config_entry--connectionattempts)
* [`connecttimeout`](#-ssh--client--host_config_entry--connecttimeout)
* [`controlmaster`](#-ssh--client--host_config_entry--controlmaster)
* [`controlpath`](#-ssh--client--host_config_entry--controlpath)
* [`dynamicforward`](#-ssh--client--host_config_entry--dynamicforward)
* [`enablesshkeysign`](#-ssh--client--host_config_entry--enablesshkeysign)
* [`escapechar`](#-ssh--client--host_config_entry--escapechar)
* [`exitonforwardfailure`](#-ssh--client--host_config_entry--exitonforwardfailure)
* [`forwardagent`](#-ssh--client--host_config_entry--forwardagent)
* [`forwardx11`](#-ssh--client--host_config_entry--forwardx11)
* [`forwardx11trusted`](#-ssh--client--host_config_entry--forwardx11trusted)
* [`gatewayports`](#-ssh--client--host_config_entry--gatewayports)
* [`globalknownhostsfile`](#-ssh--client--host_config_entry--globalknownhostsfile)
* [`gssapiauthentication`](#-ssh--client--host_config_entry--gssapiauthentication)
* [`gssapidelegatecredentials`](#-ssh--client--host_config_entry--gssapidelegatecredentials)
* [`gssapikeyexchange`](#-ssh--client--host_config_entry--gssapikeyexchange)
* [`gssapirenewalforcesrekey`](#-ssh--client--host_config_entry--gssapirenewalforcesrekey)
* [`gssapitrustdns`](#-ssh--client--host_config_entry--gssapitrustdns)
* [`hashknownhosts`](#-ssh--client--host_config_entry--hashknownhosts)
* [`hostbasedauthentication`](#-ssh--client--host_config_entry--hostbasedauthentication)
* [`hostkeyalgorithms`](#-ssh--client--host_config_entry--hostkeyalgorithms)
* [`hostkeyalias`](#-ssh--client--host_config_entry--hostkeyalias)
* [`hostname`](#-ssh--client--host_config_entry--hostname)
* [`identitiesonly`](#-ssh--client--host_config_entry--identitiesonly)
* [`identityfile`](#-ssh--client--host_config_entry--identityfile)
* [`kbdinteractiveauthentication`](#-ssh--client--host_config_entry--kbdinteractiveauthentication)
* [`kbdinteractivedevices`](#-ssh--client--host_config_entry--kbdinteractivedevices)
* [`localcommand`](#-ssh--client--host_config_entry--localcommand)
* [`localforward`](#-ssh--client--host_config_entry--localforward)
* [`ssh_loglevel`](#-ssh--client--host_config_entry--ssh_loglevel)
* [`macs`](#-ssh--client--host_config_entry--macs)
* [`nohostauthenticationforlocalhost`](#-ssh--client--host_config_entry--nohostauthenticationforlocalhost)
* [`numberofpasswordprompts`](#-ssh--client--host_config_entry--numberofpasswordprompts)
* [`passwordauthentication`](#-ssh--client--host_config_entry--passwordauthentication)
* [`permitlocalcommand`](#-ssh--client--host_config_entry--permitlocalcommand)
* [`port`](#-ssh--client--host_config_entry--port)
* [`preferredauthentications`](#-ssh--client--host_config_entry--preferredauthentications)
* [`protocol`](#-ssh--client--host_config_entry--protocol)
* [`proxycommand`](#-ssh--client--host_config_entry--proxycommand)
* [`pubkeyauthentication`](#-ssh--client--host_config_entry--pubkeyauthentication)
* [`rekeylimit`](#-ssh--client--host_config_entry--rekeylimit)
* [`remoteforward`](#-ssh--client--host_config_entry--remoteforward)
* [`rhostsrsaauthentication`](#-ssh--client--host_config_entry--rhostsrsaauthentication)
* [`rsaauthentication`](#-ssh--client--host_config_entry--rsaauthentication)
* [`sendenv`](#-ssh--client--host_config_entry--sendenv)
* [`serveralivecountmax`](#-ssh--client--host_config_entry--serveralivecountmax)
* [`serveraliveinterval`](#-ssh--client--host_config_entry--serveraliveinterval)
* [`smartcarddevice`](#-ssh--client--host_config_entry--smartcarddevice)
* [`stricthostkeychecking`](#-ssh--client--host_config_entry--stricthostkeychecking)
* [`tcpkeepalive`](#-ssh--client--host_config_entry--tcpkeepalive)
* [`tunnel`](#-ssh--client--host_config_entry--tunnel)
* [`tunneldevice`](#-ssh--client--host_config_entry--tunneldevice)
* [`useprivilegedport`](#-ssh--client--host_config_entry--useprivilegedport)
* [`user`](#-ssh--client--host_config_entry--user)
* [`userknownhostsfile`](#-ssh--client--host_config_entry--userknownhostsfile)
* [`verifyhostkeydns`](#-ssh--client--host_config_entry--verifyhostkeydns)
* [`visualhostkey`](#-ssh--client--host_config_entry--visualhostkey)
* [`xauthlocation`](#-ssh--client--host_config_entry--xauthlocation)

##### <a name="-ssh--client--host_config_entry--target"></a>`target`

Data type: `Stdlib::Absolutepath`

Absolute path to the ssh_config file to manage.

Default value: `'/etc/ssh/ssh_config'`

##### <a name="-ssh--client--host_config_entry--address_family"></a>`address_family`

Data type: `Enum['any', 'inet', 'inet6']`

The IP Address family to use when connecting.
Valid options: 'any', 'inet', 'inet6'.

Default value: `'any'`

##### <a name="-ssh--client--host_config_entry--batchmode"></a>`batchmode`

Data type: `Boolean`

If set to true, passphrase/password querying will
be disabled. This option is useful in scripts and other batch jobs where no
user is present to supply the password.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--bindaddress"></a>`bindaddress`

Data type: `Optional[Simplib::Host]`

Use the specified address on the local machine as
the source address of the connection. Only useful on systems with more than
one address. Note that this option does not work if UsePrivilegedPort is set
to false.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--challengeresponseauthentication"></a>`challengeresponseauthentication`

Data type: `Boolean`

Specifies whether to use
challenge-response authentication.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--checkhostip"></a>`checkhostip`

Data type: `Boolean`

If this flag is set to true, ssh will
additionally check the host IP address in the known_hosts file. This allows
ssh to detect if a host key changed due to DNS spoofing and will add
addresses of destination hosts to ~/.ssh/known_hosts in the process,
regardless of the setting of StrictHostKeyChecking.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--cipher"></a>`cipher`

Data type: `Enum['blowfish', '3des', 'des']`

Specifies the cipher to use for encrypting the session
in protocol version 1. Valid Options: 'blowfish', '3des', 'des'.

Default value: `'3des'`

##### <a name="-ssh--client--host_config_entry--ciphers"></a>`ciphers`

Data type: `Optional[Array[String]]`

Specifies the ciphers allowed for protocol version 2 in
order of preference. When unset, a strong set of ciphers is
automatically selected by this class, taking into account whether
the server is in FIPS mode.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--clearallforwardings"></a>`clearallforwardings`

Data type: `Boolean`

Specifies that all local, remote, and
dynamic port forwardings specified in the configuration files or on the
command line be cleared.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--compression"></a>`compression`

Data type: `Boolean`

Specifies whether to use compression.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--compressionlevel"></a>`compressionlevel`

Data type: `Integer[1,9]`

Specifies the compression level to use if
compression is enabled.

Default value: `6`

##### <a name="-ssh--client--host_config_entry--connectionattempts"></a>`connectionattempts`

Data type: `Integer[1]`

Specifies the number of tries (one per
second) to make before exiting.

Default value: `1`

##### <a name="-ssh--client--host_config_entry--connecttimeout"></a>`connecttimeout`

Data type: `Integer[0]`

Specifies the timeout (in seconds) used when
connecting to the SSH server, instead of using the default system TCP
timeout.

Default value: `0`

##### <a name="-ssh--client--host_config_entry--controlmaster"></a>`controlmaster`

Data type: `Enum['yes','no','ask']`

Enables the sharing of multiple sessions over a
single network connection.

Default value: `'no'`

##### <a name="-ssh--client--host_config_entry--controlpath"></a>`controlpath`

Data type: `Optional[Variant[Stdlib::Absolutepath, Enum['none']]]`

Specify the path to the control socket used for
connection sharing as set by controlmaster.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--dynamicforward"></a>`dynamicforward`

Data type: `Optional[Variant[Simplib::Port, Simplib::Host::Port]]`

Specifies that a TCP port on the local machine
be forwarded over the secure channel, and the application protocol is then
used to determine where to connect to from the remote machine.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--enablesshkeysign"></a>`enablesshkeysign`

Data type: `Boolean`

Setting this option to true enables the use
of the helper program ssh-keysign during HostbasedAuthentication.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--escapechar"></a>`escapechar`

Data type: `Pattern[/^[[:graph:]]$/, /^\^[[:alpha:]]$/, /^none$/]`

Sets the default escape character. Must be a single character.

Default value: `'~'`

##### <a name="-ssh--client--host_config_entry--exitonforwardfailure"></a>`exitonforwardfailure`

Data type: `Boolean`

Specifies whether ssh should terminate
the connection if it cannot set up all requested dynamic, tunnel, local, and
remote port forwardings.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--forwardagent"></a>`forwardagent`

Data type: `Boolean`

Specifies whether the connection to the
authentication agent (if any) will be forwarded to the remote machine.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--forwardx11"></a>`forwardx11`

Data type: `Boolean`

Specifies whether X11 connections will be
automatically redirected over the secure channel and DISPLAY set.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--forwardx11trusted"></a>`forwardx11trusted`

Data type: `Boolean`

If set to true, remote X11 clients will
have full access to the original X11 display.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--gatewayports"></a>`gatewayports`

Data type: `Boolean`

Specifies whether remote hosts are allowed to
connect to local forwarded ports.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--globalknownhostsfile"></a>`globalknownhostsfile`

Data type: `Optional[Array[Stdlib::Absolutepath]]`

Specifies one or more files to use for
the global host key database.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--gssapiauthentication"></a>`gssapiauthentication`

Data type: `Boolean`

Specifies whether user authentication
based on GSSAPI is allowed. If the system is connected to an IPA domain,
this will be set to true, regardless of this parameter. It uses the
`ipa` fact to determine domain membership.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--gssapidelegatecredentials"></a>`gssapidelegatecredentials`

Data type: `Boolean`

Forward credentials to the server.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--gssapikeyexchange"></a>`gssapikeyexchange`

Data type: `Boolean`

Specifies whether key exchange based on

Default value: `false`

##### <a name="-ssh--client--host_config_entry--gssapirenewalforcesrekey"></a>`gssapirenewalforcesrekey`

Data type: `Boolean`

If set to true then renewal of

Default value: `false`

##### <a name="-ssh--client--host_config_entry--gssapitrustdns"></a>`gssapitrustdns`

Data type: `Boolean`

Set to true to indicate that the DNS is

Default value: `false`

##### <a name="-ssh--client--host_config_entry--hashknownhosts"></a>`hashknownhosts`

Data type: `Boolean`

Indicates that SSH should hash host names and
addresses when they are added to known hosts.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--hostbasedauthentication"></a>`hostbasedauthentication`

Data type: `Boolean`

Specifies whether to try rhosts
based authentication with public key authentication.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--hostkeyalgorithms"></a>`hostkeyalgorithms`

Data type: `Optional[Array[String]]`

Specifies the host key algorithms that the
client wants to use in order of preference.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--hostkeyalias"></a>`hostkeyalias`

Data type: `Optional[String]`

Specifies an alias that should be used instead of
the real host name when looking up or saving the host key in the host key
database files.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--hostname"></a>`hostname`

Data type: `Optional[Simplib::Host]`

Specifies the real hostname to log into.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--identitiesonly"></a>`identitiesonly`

Data type: `Boolean`

Specifies that ssh should only use the
authentication identity and certificate files explicitly configured in the
ssh_config files or passed on the ssh command-line, even if ssh-agent or
a PKCS11Provider offers more identities.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--identityfile"></a>`identityfile`

Data type: `Optional[String]`

Specifies a file from which the user's DSA,
ECDSA, Ed25519 or RSA authentication identity is read.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--kbdinteractiveauthentication"></a>`kbdinteractiveauthentication`

Data type: `Boolean`

Specifies whether to use
keyboard-interactive authentication.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--kbdinteractivedevices"></a>`kbdinteractivedevices`

Data type: `Optional[Array[String]]`

Specifies the list of methods to use in
keyboard-interactive authentication. Multiple method names must be
comma-separated.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--localcommand"></a>`localcommand`

Data type: `Optional[String]`

Specifies a command to execute on the local
machine after successfully connecting to the server.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--localforward"></a>`localforward`

Data type: `Optional[String]`

Specifies that a TCP port on the local machine be
forwarded over the secure channel to the specified host and port from the
remote machine. The first argument must be [bind_address:]port and the
second argument must be host:hostport.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--ssh_loglevel"></a>`ssh_loglevel`

Data type: `Ssh::Loglevel`

Gives the verbosity level that is used when
logging messages. Valid options: 'QUIET', 'FATAL', 'ERROR', 'INFO',
'VERBOSE', 'DEBUG', 'DEBUG1', 'DEBUG2', and 'DEBUG3'.

Default value: `'INFO'`

##### <a name="-ssh--client--host_config_entry--macs"></a>`macs`

Data type: `Optional[Array[String]]`

Specifies the MAC (message authentication code) algorithms
in order of preference.  When unset, a strong set of algorithms is
automatically selected by this class, taking into account whether
the server is in FIPS mode.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--nohostauthenticationforlocalhost"></a>`nohostauthenticationforlocalhost`

Data type: `Boolean`

This option can be used if
the home directory is shared across machines. In this case localhost will
refer to a different machine on each of the machines and the user will get
many warnings about changed host keys. However, this option disables host
authentication for localhost.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--numberofpasswordprompts"></a>`numberofpasswordprompts`

Data type: `Integer[1]`

Specifies the number of password
prompts before giving up.

Default value: `3`

##### <a name="-ssh--client--host_config_entry--passwordauthentication"></a>`passwordauthentication`

Data type: `Boolean`

Specifies whether to use password
authentication.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--permitlocalcommand"></a>`permitlocalcommand`

Data type: `Boolean`

Allow local command execution via the
LocalCommand option or using the !command escape sequence.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--port"></a>`port`

Data type: `Simplib::Port`

Specifies the port number to connect on the remote host.

Default value: `22`

##### <a name="-ssh--client--host_config_entry--preferredauthentications"></a>`preferredauthentications`

Data type: `Array[Ssh::Authentications]`

Specifies the order in which the
client should try authentication methods. The order will be determined from
the start of the array to the end of the array. Default:
['publickey','hostbased','keyboard-interactive','password']

Default value:

```puppet
[ 'publickey',
                                                                                              'hostbased',
                                                                                              'keyboard-interactive',
                                                                                              'password' ]
```

##### <a name="-ssh--client--host_config_entry--protocol"></a>`protocol`

Data type: `Variant[Integer[1,2], Enum['2,1']]`

Specifies the protocol versions SSH should support.

Default value: `2`

##### <a name="-ssh--client--host_config_entry--proxycommand"></a>`proxycommand`

Data type: `Optional[String]`

Specifies the command to use to connect to the
server.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--pubkeyauthentication"></a>`pubkeyauthentication`

Data type: `Boolean`

Specifies whether to try public key
authentication.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--rekeylimit"></a>`rekeylimit`

Data type: `Optional[String]`

Specifies the maximum amount of data that may be
transmitted before the session key is renegotiated, optionally followed a
maximum amount of time that may pass before the session key is renegotiated.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--remoteforward"></a>`remoteforward`

Data type: `Optional[String]`

Specifies that a TCP port on the remote machine
be forwarded over the secure channel to the specified host and port from the
local machine.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--rhostsrsaauthentication"></a>`rhostsrsaauthentication`

Data type: `Boolean`

Specifies whether to try rhosts based
authentication with RSA host authentication.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--rsaauthentication"></a>`rsaauthentication`

Data type: `Boolean`

Specifies whether to try RSA Authentication.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--sendenv"></a>`sendenv`

Data type: `Array[String]`

Specifies what variables from the local environ
should be sent to the server.

Default value:

```puppet
[ 'LANG',
                                                                                              'LC_CTYPE',
                                                                                              'LC_NUMERIC',
                                                                                              'LC_TIME',
                                                                                              'LC_COLLATE',
                                                                                              'LC_MONETARY',
                                                                                              'LC_MESSAGES',
                                                                                              'LC_PAPER',
                                                                                              'LC_NAME',
                                                                                              'LC_ADDRESS',
                                                                                              'LC_TELEPHONE',
                                                                                              'LC_MEASUREMENT',
                                                                                              'LC_IDENTIFICATION',
                                                                                              'LC_ALL' ]
```

##### <a name="-ssh--client--host_config_entry--serveralivecountmax"></a>`serveralivecountmax`

Data type: `Integer[1]`

Sets the number of server alive messages
(see below) which may be sent without ssh receiving any messages back from
the server.

Default value: `3`

##### <a name="-ssh--client--host_config_entry--serveraliveinterval"></a>`serveraliveinterval`

Data type: `Integer[0]`

Sets a timeout interval in seconds after
which if no data has been received from the server. The default is 0,
indicating that these messages will not be sent to the server.

Default value: `0`

##### <a name="-ssh--client--host_config_entry--smartcarddevice"></a>`smartcarddevice`

Data type: `Optional[String]`

Specifies which smartcard device to use.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--stricthostkeychecking"></a>`stricthostkeychecking`

Data type: `Enum['yes','no','ask']`

If set to yes, ssh will never
automatically add host keys to the known_hosts file, and refuses to connect
to hosts whose keys have changed.  If this flag is set to "ask", new host
keys will be added to the user known host files only after the user has
confirmed that is what they really want to do, and ssh will refuse to
connect to hosts whose host key has changed. Valid Options: 'yes', 'no',
'ask'

Default value: `'ask'`

##### <a name="-ssh--client--host_config_entry--tcpkeepalive"></a>`tcpkeepalive`

Data type: `Boolean`

Specifies whether the system should send TCP
keepalive messages to the other side.

Default value: `true`

##### <a name="-ssh--client--host_config_entry--tunnel"></a>`tunnel`

Data type: `Enum['yes','no','point-to-point','ethernet']`

If 'yes', request device forwarding between the client and
server.

Default value: `'no'`

##### <a name="-ssh--client--host_config_entry--tunneldevice"></a>`tunneldevice`

Data type: `Optional[String]`

Specifies the devices to open on the client and
the server.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--useprivilegedport"></a>`useprivilegedport`

Data type: `Boolean`

Specifies whether to use a privileged port
for outgoing connections.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--user"></a>`user`

Data type: `Optional[String]`

Specifies the user to log in as.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--userknownhostsfile"></a>`userknownhostsfile`

Data type: `Optional[Array[Stdlib::Absolutepath]]`

Specifies one or more files to use for the
user host key database, separated by whitespace.

Default value: `undef`

##### <a name="-ssh--client--host_config_entry--verifyhostkeydns"></a>`verifyhostkeydns`

Data type: `Enum['yes','no','ask']`

Specifies whether to verify the remote key
using DNS and SSHFP resource records.

Default value: `'no'`

##### <a name="-ssh--client--host_config_entry--visualhostkey"></a>`visualhostkey`

Data type: `Boolean`

If this flag is set to true, an ASCII art
representation of the remote host key fingerprint is printed in addition to
the fingerprint string at login and for unknown host keys.

Default value: `false`

##### <a name="-ssh--client--host_config_entry--xauthlocation"></a>`xauthlocation`

Data type: `Stdlib::Absolutepath`

Specifies the full pathname of the xauth
program.

Default value: `'/usr/bin/xauth'`

## Resource types

### <a name="sshkey_prune"></a>`sshkey_prune`

The file that you wish to prune

#### Properties

The following properties are available in the `sshkey_prune` type.

##### `prune`

Valid values: `true`, `false`

Whether or not to prune the file in $name

Default value: `true`

#### Parameters

The following parameters are available in the `sshkey_prune` type.

* [`name`](#-sshkey_prune--name)
* [`provider`](#-sshkey_prune--provider)

##### <a name="-sshkey_prune--name"></a>`name`

namevar

The file that you wish to prune

##### <a name="-sshkey_prune--provider"></a>`provider`

The specific backend to use for this `sshkey_prune` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Functions

### <a name="ssh--add_sshd_config"></a>`ssh::add_sshd_config`

Type: Puppet Language

Add a sshd_config entry if it is not in the remove list

#### `ssh::add_sshd_config(String[1] $key, Any $value, Variant[Array[String[1]],Undef] $remove_keys, Array[Type[Catalogentry]] $resources_to_notify = [ Service['sshd'] ])`

Add a sshd_config entry if it is not in the remove list

Returns: `Nil`

##### `key`

Data type: `String[1]`

The name of the sshd configuration parameter

##### `value`

Data type: `Any`

The value of the sshd configuration parameter

##### `remove_keys`

Data type: `Variant[Array[String[1]],Undef]`

List of sshd configuration parameters to be removed

##### `resources_to_notify`

Data type: `Array[Type[Catalogentry]]`

Catalog resources to notify when the sshd
configuration has changed

### <a name="ssh--autokey"></a>`ssh::autokey`

Type: Ruby 4.x API

user.

Keys are stored in
  "Puppet[:vardir]/simp/environments/<environment>/simp_autofiles/ssh_autokeys"

Note: This function if marked as an InternalFunction because it
changes the state of the system by writing key files.

#### `ssh::autokey(String $username, Optional[Hash] $options)`

The following options are supported:
- 'key_strength': key length, Integer, defaults to 2048
- 'return_private': whether to return the private key, Boolean, defaults to false
NOTE: A minimum key strength of 1024 is enforced!

Returns: `String` The public key of the user

##### `username`

Data type: `String`

username for which SSH key pairs will be generated

##### `options`

Data type: `Optional[Hash]`

Options hash

#### `ssh::autokey(String $username, Optional[Integer] $key_strength, Optional[Boolean] $return_private)`

NOTE: A minimum key strength of 1024 is enforced!

Returns: `String` The public key of the user or the private key if
return_private is specified.

##### `username`

Data type: `String`

username for which SSH key pairs will be generated

##### `key_strength`

Data type: `Optional[Integer]`

key length, defaults to 2048

##### `return_private`

Data type: `Optional[Boolean]`

whether to return the private key, defaults to false

### <a name="ssh--config_bool_translate"></a>`ssh::config_bool_translate`

Type: Ruby 4.x API

All other values are passed-through unchanged

#### `ssh::config_bool_translate(String $config_item)`

The ssh::config_bool_translate function.

Returns: `Any` transformed config_item

##### `config_item`

Data type: `String`

Configuration item to be translated

#### `ssh::config_bool_translate(Boolean $config_item)`

The ssh::config_bool_translate function.

Returns: `Any` transformed config_item

##### `config_item`

Data type: `Boolean`

Configuration item to be translated

### <a name="ssh--format_host_entry_for_sorting"></a>`ssh::format_host_entry_for_sorting`

Type: Ruby 4.x API

wildcards and question marks.

The output is intended for use with the simpcat_fragment type and is *not*
meant for use as a host entry itself.

The general idea is that it places all items at the bottom of the list
using zzzz, then sorts by question marks first per section then wildcards
per section.

Example:
Input: '*'
Output: 'zzzz98_st__'

Input: '*.foo.bar'
Output: 'zzzz96_st__.foo.bar'

Input: 'foo.?.bar'
Output: 'foo.zzzz95_qu__.bar'

Input: 'foo?.*.bar'
Output: 'foozzzz96_qu__.zzzz95_st__.bar'

#### `ssh::format_host_entry_for_sorting(String $host_entry)`

wildcards and question marks.

The output is intended for use with the simpcat_fragment type and is *not*
meant for use as a host entry itself.

The general idea is that it places all items at the bottom of the list
using zzzz, then sorts by question marks first per section then wildcards
per section.

Example:
Input: '*'
Output: 'zzzz98_st__'

Input: '*.foo.bar'
Output: 'zzzz96_st__.foo.bar'

Input: 'foo.?.bar'
Output: 'foo.zzzz95_qu__.bar'

Input: 'foo?.*.bar'
Output: 'foozzzz96_qu__.zzzz95_st__.bar'

Returns: `Any` transformed host_entry

##### `host_entry`

Data type: `String`

SSH host entry, which may contain wildcards

### <a name="ssh--global_known_hosts"></a>`ssh::global_known_hosts`

Type: Ruby 4.x API

removing duplicates, and creating catalog resources that are found

 Note: This function if marked as an InternalFunction because it
 changes the state of the system by adding/removing files and
 adding catalog resources.

#### `ssh::global_known_hosts(Optional[Integer] $expire_days)`

removing duplicates, and creating catalog resources that are found

 Note: This function if marked as an InternalFunction because it
 changes the state of the system by adding/removing files and
 adding catalog resources.

Returns: `None`

##### `expire_days`

Data type: `Optional[Integer]`

expire time in days; defaults to 7; value of 0
means never purge

### <a name="ssh--parse_ssh_pubkey"></a>`ssh::parse_ssh_pubkey`

Type: Puppet Language

Take an ssh pubkey that looks like:
  ssh-rsa jdlkfgjsdfo;i... user@domain.com
and turn it into a hash, usable in the ssh_authorized_key type

#### `ssh::parse_ssh_pubkey(String $key)`

Take an ssh pubkey that looks like:
  ssh-rsa jdlkfgjsdfo;i... user@domain.com
and turn it into a hash, usable in the ssh_authorized_key type

Returns: `Hash`

##### `key`

Data type: `String`

The ssh key, can be pasted from ~/.ssh/id_rsa.pub or similar

## Data types

### <a name="Ssh--Authentications"></a>`Ssh::Authentications`

Valid SSH Authentication Settings

Alias of `Enum['publickey', 'hostbased', 'keyboard-interactive', 'password', 'gssapi-with-mic']`

### <a name="Ssh--Loglevel"></a>`Ssh::Loglevel`

Valid SSH Loglevels

Alias of `Enum['QUIET', 'FATAL', 'ERROR', 'INFO', 'VERBOSE', 'DEBUG', 'DEBUG1', 'DEBUG2', 'DEBUG3']`

### <a name="Ssh--PermitRootLogin"></a>`Ssh::PermitRootLogin`

Valid Settings for PermitRootLogin

Alias of `Variant[Boolean, Enum['prohibit-password', 'without-password', 'forced-commands-only']]`

### <a name="Ssh--Syslogfacility"></a>`Ssh::Syslogfacility`

Valid SSH Syslog Facility Settings

Alias of `Enum['DAEMON', 'USER', 'AUTH', 'AUTHPRIV', 'LOCAL0', 'LOCAL1', 'LOCAL2', 'LOCAL3', 'LOCAL4', 'LOCAL5', 'LOCAL6', 'LOCAL7']`

